var path = require('path');

var loadActions = require('./load-actions');
var toInterpretRouteSyntax = require('./to-interpret-route-syntax');

module.exports = function(sails) {

  return {

    /**
     * Default configuration
     */

    defaults: {

      __configKey__: {

        actionsDir: path.resolve(sails.config.appPath,'api','actions'),

      }
    },

    /**
     * Before any hooks have begun loading...
     * (called automatically by Sails core)
     */
    configure: function() {
      sails.actions = {};
    },


    initialize: function(cb) {

      var self = this;

      // Handle the {action: 'some-action-identity'} route syntax
      sails.on('route:typeUnknown', toInterpretRouteSyntax(sails));

      // Handle hook reload event
      sails.on('hook:actions:reload', function(actions) {
        self.reload(actions);
      });

      // Load actions from the specified folder
      loadActions.apply(this, [sails, cb]);

    },

    reload: function(actions) {
      // If we received an explicit set of actions to load, use them.
      if (actions) {
        sails.actions = actions;
        return;
      }
      // Otherwise reload actions from disk.
      loadActions.apply(this, [sails, function(err) {
        if (err) {throw err;}
      }]);
    }

  };

};
