var assert = require('assert');
var lifecycle = require('./helpers/lifecycle');

describe('basic test', function() {

  var app;
  before(function(done) {
    lifecycle.liftSails({log: {level: 'error'}},function(err, _sails) {
      if (err) {return done(err);}
      app = _sails;
      return done();
    });
  });

  after(function(done) {
    lifecycle.lowerSails(app, done);
  });


  describe('in the root folder', function() {

    describe('with valid inputs', function() {

      it('should return the correct response', function(done) {

        app.request({
          url: '/hi',
          params: {name: 'scott'},
          method: 'get'
        }, function(err, response, body) {
          if (err) {return done(err);}
          assert.equal(body, 'Hi scott');
          return done();
        });

      });

    });

    describe('with invalid inputs', function() {

      it('should return the correct error', function(done) {

        app.request({
          url: '/hi',
          method: 'get'
        }, function(err, response, body) {
          if (err) {
            assert.equal(err.body.code, 'E_MISSING_OR_INVALID_PARAMS');
            assert.equal(err.body.errors[0].code, 'E_INPUT_REQUIRED');
            assert.equal(err.body.errors[0].input, 'name');
            return done();
          }        
          return done(new Error('Should have thrown an error!'));
        });
      });

    });  

  });
  
  describe('in a subfolder', function() {  

    describe('with valid inputs', function() {

      it('should return the correct response', function(done) {

        app.request({
          url: '/user/hello',
          params: {name: 'scott'},
          method: 'get'
        }, function(err, response, body) {
          if (err) {return done(err);}
          assert.equal(body, 'Hello scott');
          return done();
        });

      });    

      it('should return the correct status code', function(done) {

        app.request({
          url: '/foo/scold',
          params: {name: 'scott'},
          method: 'get'
        }, function(err, response, body) {
          if (err) {
            assert.equal(err.body, 'You are bad, scott');
            assert.equal(err.status, 400);            
            return done();
          }
          return done(new Error('Should have thrown an error!'));
        });

      });          

    });

  });


});
